@@ -32,6 +32,6 @@ class get_player:
 
 		if not json["success"]:
 
-			raise APIError(self.api)
+			return None
 		else:
 			return Player(json)
\ No newline at end of file
